pydevDAG._errors module — pydevDAG 1.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- pydevDAG »
- pydevDAG package »

# pydevDAG._errors module

## pydevDAG._errors

Errors raised by this module.

exception `pydevDAG._errors.` `DAGEnvironmentError`

  Bases: `pydevDAG._errors.DAGError`

  A surprise in the environment in which the DAG is being constructed.

exception `pydevDAG._errors.` `DAGError`

  Bases: `exceptions.Exception`

  Generic error.

exception `pydevDAG._errors.` `DAGGraphError`

  Bases: `pydevDAG._errors.DAGError`

  Raised if something is wrong with graph, e.g., missing attributes.

exception `pydevDAG._errors.` `DAGValueError`

  Bases: `pydevDAG._errors.DAGError`

  Raised if bad value passed.

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- pydevDAG »
- pydevDAG package »